<?php

namespace Drupal\commerce_boncard\Form;

use Drupal\Core\Entity\ContentEntityForm;
use Drupal\Core\Form\FormStateInterface;

/**
 * Form controller for the boncard transaction entity edit forms.
 */
class BoncardForm extends ContentEntityForm {

  /**
   * {@inheritdoc}
   */
  public function save(array $form, FormStateInterface $form_state) {

    $entity = $this->getEntity();
    $result = $entity->save();
    $link = $entity->toLink($this->t('View'))->toRenderable();

    $message_arguments = ['%label' => $this->entity->label()];
    $logger_arguments = $message_arguments + ['link' => render($link)];

    if ($result == SAVED_NEW) {
      $this->messenger()->addStatus($this->t('New boncard transaction %label has been created.', $message_arguments));
      $this->logger('commerce_boncard')->notice('Created new boncard transaction %label', $logger_arguments);
    }
    else {
      $this->messenger()->addStatus($this->t('The boncard transaction %label has been updated.', $message_arguments));
      $this->logger('commerce_boncard')->notice('Updated new boncard transaction %label.', $logger_arguments);
    }

    $form_state->setRedirect('entity.commerce_boncard.canonical', ['commerce_boncard' => $entity->id()]);
  }

  /**
   * {@inheritdoc}
   */
  protected function actions(array $form, FormStateInterface $form_state) {
    $actions = parent::actions($form, $form_state);

    if (!$this->entity->isNew() && $this->entity->hasLinkTemplate('delete-form')) {
      $route_info = $this->entity->toUrl('delete-form')->setRouteParameter('commerce_order', $this->entity->getOrderId());
      if ($this->getRequest()->query->has('destination')) {
        $query = $route_info->getOption('query');
        $query['destination'] = $this->getRequest()->query->get('destination');
        $route_info->setOption('query', $query);
      }
      $actions['delete'] = [
        '#type' => 'link',
        '#title' => $this->t('Delete'),
        '#access' => $this->entity->access('delete'),
        '#attributes' => [
          'class' => ['button', 'button--danger'],
        ],
      ];
      $actions['delete']['#url'] = $route_info;
    }

    return $actions;
  }

}
